@@ -4,8 +4,8 @@
     https://github.com/Evolutionary-Intelligence/pypop/wiki/Correctness-Validation-of-Optimizers.md
 """
 import unittest
-
 import time
+
 import numpy as np
 
 from pypop7.benchmarks.base_functions import ellipsoid, rosenbrock, rastrigin
@@ -28,9 +28,8 @@ class TestLMCMA(unittest.TestCase):
                        'seed_rng': 0,
                        'x': 4 * np.ones((ndim_problem,)),  # mean
                        'sigma': 0.1,
-                       'verbose_frequency': 2000,
-                       'record_fitness': True,
-                       'record_fitness_frequency': 200000}
+                       'verbose': 5000,
+                       'saving_fitness': 200000}
             solver = Solver(problem, options)
             results = solver.optimize()
             print(results)
