@@ -3,6 +3,8 @@ from pypop7.optimizers.rs.prs import PRS
 from pypop7.optimizers.rs.rhc import RHC
 from pypop7.optimizers.rs.arhc import ARHC
 from pypop7.optimizers.rs.srs import SRS
+from pypop7.optimizers.rs.bes import BES
 
 
-__all__ = [RS, PRS, RHC, ARHC, SRS]
+__all__ = [RS, PRS, RHC, ARHC, SRS,
+           BES]  # especially for large-scale black-box optimization
